==> haskell-unliftio-0.2.7.0-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-unliftio.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unliftio
version: 0.2.7.0
id: unliftio-0.2.7.0-EQSuStuI71XDSnLuao58Rv
key: unliftio-0.2.7.0-EQSuStuI71XDSnLuao58Rv
license: MIT
copyright: 2017 FP Complete
maintainer: michael@snoyman.com
author: Michael Snoyman, Francesco Mazzoli
homepage: https://github.com/fpco/unliftio/tree/master/unliftio#readme
synopsis: The MonadUnliftIO typeclass for unlifting monads to IO (batteries included)
description:
    Please see the documentation and README at <https://www.stackage.org/package/unliftio>
category: Control
abi: f1811b15311320a9a9881f36fa288bf4
exposed: True
exposed-modules:
    UnliftIO UnliftIO.Async UnliftIO.Chan UnliftIO.Concurrent
    UnliftIO.Directory UnliftIO.Environment UnliftIO.Exception
    UnliftIO.Foreign UnliftIO.IO UnliftIO.IORef UnliftIO.MVar
    UnliftIO.Process UnliftIO.STM UnliftIO.Temporary UnliftIO.Timeout
hidden-modules: Paths_unliftio
import-dirs: /usr/lib/ghc-8.4.3/site-local/unliftio-0.2.7.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/unliftio-0.2.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/unliftio-0.2.7.0
hs-libraries: HSunliftio-0.2.7.0-EQSuStuI71XDSnLuao58Rv
depends:
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe base-4.11.1.0 deepseq-1.4.3.0
    directory-1.3.1.5 filepath-1.4.2 process-1.6.3.0 stm-2.4.5.0
    time-1.8.0.2 transformers-0.5.5.0
    unliftio-core-0.1.1.0-LMRC2BJekXQHTjQ89kypYp unix-2.7.2.2
abi-depends: async-2.2.1-B6m2kYywRJu7nicgTBxsJe=32776142fda961cc693aa4db742773f9
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
             stm-2.4.5.0=4e743cb5a370ac3fbade528432951c3f
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             unliftio-core-0.1.1.0-LMRC2BJekXQHTjQ89kypYp=1c7a6d4dd36bdfc42b4932ebc332e3b3
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
haddock-interfaces: /usr/share/doc/haskell-unliftio/html/unliftio.haddock
haddock-html: /usr/share/doc/haskell-unliftio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unliftio-0.2.7.0-18-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-unliftio.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unliftio
version: 0.2.7.0
id: unliftio-0.2.7.0-7ZRg6vBOAnJKhVzuKPAekD
key: unliftio-0.2.7.0-7ZRg6vBOAnJKhVzuKPAekD
license: MIT
copyright: 2017 FP Complete
maintainer: michael@snoyman.com
author: Michael Snoyman, Francesco Mazzoli
homepage: https://github.com/fpco/unliftio/tree/master/unliftio#readme
synopsis: The MonadUnliftIO typeclass for unlifting monads to IO (batteries included)
description:
    Please see the documentation and README at <https://www.stackage.org/package/unliftio>
category: Control
abi: 8fd70228491f8061a2db66cb334cc156
exposed: True
exposed-modules:
    UnliftIO UnliftIO.Async UnliftIO.Chan UnliftIO.Concurrent
    UnliftIO.Directory UnliftIO.Environment UnliftIO.Exception
    UnliftIO.Foreign UnliftIO.IO UnliftIO.IORef UnliftIO.MVar
    UnliftIO.Process UnliftIO.STM UnliftIO.Temporary UnliftIO.Timeout
hidden-modules: Paths_unliftio
import-dirs: /usr/lib/ghc-8.4.3/site-local/unliftio-0.2.7.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/unliftio-0.2.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/unliftio-0.2.7.0
hs-libraries: HSunliftio-0.2.7.0-7ZRg6vBOAnJKhVzuKPAekD
depends:
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe base-4.11.1.0 deepseq-1.4.3.0
    directory-1.3.1.5 filepath-1.4.2 process-1.6.3.0 stm-2.4.5.0
    time-1.8.0.2 transformers-0.5.5.0
    unliftio-core-0.1.1.0-LMRC2BJekXQHTjQ89kypYp unix-2.7.2.2
abi-depends: async-2.2.1-B6m2kYywRJu7nicgTBxsJe=32776142fda961cc693aa4db742773f9
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
             stm-2.4.5.0=4e743cb5a370ac3fbade528432951c3f
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             unliftio-core-0.1.1.0-LMRC2BJekXQHTjQ89kypYp=1c7a6d4dd36bdfc42b4932ebc332e3b3
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
haddock-interfaces: /usr/share/doc/haskell-unliftio/html/unliftio.haddock
haddock-html: /usr/share/doc/haskell-unliftio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
